(panel {:keys [title extra color extra] :or {color "grey" title "Panel Title"}}
&
children)a panel displays a seq of components has a header
a panel displays a seq of components has a header
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |