ui.flexlayout


add-nodecljs

(add-node {:keys [layout-a option-a edit-a model-a]}
          {:keys [id options edit] :as node})

as-elementcljs

(as-element el)

component-panelcljs

(component-panel comp options-a)

component-uicljsmultimethod


create-modelcljs

(create-model {:keys [model options edit] :or {options {} edit {}}})

functional-compilercljs


get-datacljs

(get-data {:keys [model-a edit-a option-a]})

layoutcljs

(layout {:keys [layout-a model] :as state})

The model is tree of Node objects that define the structure of the layout. The factory is a function that takes a Node object and returns a React componeny

The model is tree of Node objects that define the structure of the layout.
The factory is a function that takes a Node object and returns a React componeny
raw docstring

make-factorycljs

(make-factory {:keys [option-a] :as state})

make-handle-actioncljs

(make-handle-action {:keys [selected-id-a] :as state})

subscribe-optionscljs

(subscribe-options option-a cell-id)

subscribe-selected-editcljs

(subscribe-selected-edit {:keys [edit-a selected-id-a] :as state})

subscribe-selected-optionscljs

(subscribe-selected-options {:keys [option-a selected-id-a] :as state})

tab-button-titlecljs

(tab-button-title {:keys [cell-id]})

title-factorycljs

cljdoc builds & hosts documentation for Clojure/Script libraries