ClojureScript only.

ui.overlay


overlay-addcljs

(overlay-add id hiccup)

Adds hiccup as an overlay to current page. hiccup needs to be a vector id needs to be a string

Adds hiccup as an overlay to current page.
hiccup needs to be a vector
id needs to be a string
raw docstring

overlay-removecljs

(overlay-remove id)

Removes an overlay that has been added with overlay-add from the dom. id needs to be a string

Removes an overlay that has been added with overlay-add from the dom.
id needs to be a string
raw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries