(add-node {:keys [layout-a option-a edit-a model-a]}
{:keys [id options edit] :as node})(as-element el)(component-panel comp options-a)(create-model {:keys [model options edit] :or {options {} edit {}}})(get-data {:keys [model-a edit-a option-a]})(layout {:keys [layout-a model] :as state})The model is tree of Node objects that define the structure of the layout. The factory is a function that takes a Node object and returns a React componeny
The model is tree of Node objects that define the structure of the layout. The factory is a function that takes a Node object and returns a React componeny
(make-factory {:keys [option-a] :as state})(make-handle-action {:keys [selected-id-a] :as state})(subscribe-options option-a cell-id)(subscribe-selected-edit {:keys [edit-a selected-id-a] :as state})(subscribe-selected-options {:keys [option-a selected-id-a] :as state})(tab-button-title {:keys [cell-id]})cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |