(overlay-add id hiccup)Adds hiccup as an overlay to current page. hiccup needs to be a vector id needs to be a string
Adds hiccup as an overlay to current page. hiccup needs to be a vector id needs to be a string
(overlay-remove id)Removes an overlay that has been added with overlay-add from the dom. id needs to be a string
Removes an overlay that has been added with overlay-add from the dom. id needs to be a string
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |